# Automator Workflow for Whisper CLI Transcription

This repository contains an Apple Automator workflow that utilizes the Whisper CLI to transcribe audio files. The workflow is designed as a Quick Action, allowing users to right-click on an audio file and transcribe it effortlessly. 

## Files Included
- `run-whisper-cli.sh`: A shell script that executes the transcription process using the Whisper CLI.
- `select-output-format.applescript`: An AppleScript that prompts the user to select the desired output format for the transcription.

## Prerequisites
1. **Whisper CLI**: Ensure you have Whisper CLI installed. Follow the installation instructions [here](https://github.com/openai/whisper).
2. **Apple Automator**: This workflow is designed to be used with Apple Automator.

## Installation and Setup
1. **Clone the Repository**:
    ```sh
    git clone <repository-url>
    cd <repository-directory>
    ```

2. **Copy the Shell Script and AppleScript**:
    - Place `run-whisper-cli.sh` and `select-output-format.applescript` in a convenient location on your Mac (e.g., `/usr/local/bin`).

3. **Make the Shell Script Executable**:
    ```sh
    chmod +x /path/to/run-whisper-cli.sh
    ```

4. **Create the Automator Workflow**:
    - Open Automator and create a new Quick Action.
    - Set the input type to `files or folders`.
    - Add a `Run AppleScript` action and paste the contents of `select-output-format.applescript`.
    - Add a `Run Shell Script` action, set the Shell to `/bin/bash`, and pass input `as arguments`.
    - Add the following code to the `Run Shell Script` action:
        ```sh
        /path/to/run-whisper-cli.sh "$@"
        ```
    - Save the workflow with a descriptive name, such as `Transcribe with Whisper`.

## Usage
1. **Select an Audio File**:
    - Right-click on the audio file you want to transcribe.
    - Choose `Quick Actions > Transcribe with Whisper` (or the name you saved the workflow as).

2. **Select Output Format**:
    - An AppleScript dialog will appear prompting you to select the desired output format (e.g., `txt`, `srt`).

3. **Transcription and Opening**:
    - The workflow will transcribe the audio file using the Whisper CLI.
    - Once transcription is complete, the resulting file will open automatically.

## Customization
- **Output Directory**: By default, the transcribed file is saved in the same directory as the audio file. You can modify the `run-whisper-cli.sh` script if you need to change this behavior.

## Troubleshooting
- Ensure you have the necessary permissions to execute the shell script and access the Whisper CLI.
- Verify that the paths specified in the Automator actions are correct.
- Check the macOS security and privacy settings if the scripts or applications are blocked.

## Contributing
Feel free to submit issues or pull requests if you have suggestions or improvements.

## License
This project is licensed under the MIT License.

## Contact
For any questions or assistance, please contact Nhan at frage@ainfach.ai